#!/bin/sh
#
# Copyright (c) Members of the EGEE Collaboration. 2004-2010.
# See http://www.eu-egee.org/partners/ for details on the copyright
# holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Authors:
# 2009-
#    Oscar Koeroo <okoeroo@nikhef.nl>
#    Mischa Sall\'e <msalle@nikhef.nl>
#    David Groep <davidg@nikhef.nl>
#    NIKHEF Amsterdam, the Netherlands
#    <grid-mw-security@nikhef.nl> 
#
# 2007-2009
#    Oscar Koeroo <okoeroo@nikhef.nl>
#    David Groep <davidg@nikhef.nl>
#    NIKHEF Amsterdam, the Netherlands
#
# 2003-2007
#    Martijn Steenbakkers <martijn@nikhef.nl>
#    Oscar Koeroo <okoeroo@nikhef.nl>
#    David Groep <davidg@nikhef.nl>
#    NIKHEF Amsterdam, the Netherlands
#

prefix=/usr
exec_prefix=/usr

LOCATION_LIB=/usr/lib64
GLOBUS_FLAVOR=
ETC_GRID_SEC="/etc/grid-security"
GSI_AUTHZ_FILE="$ETC_GRID_SEC/gsi-authz.conf"

SHARED_OBJECT_FILETYPE=".so"
GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX="liblcas_lcmaps_gt4_mapping"

GT4_INTERFACE_SHARED_OBJECT_FILE="$LOCATION_LIB"/"$GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$SHARED_OBJECT_FILETYPE"
GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE="$LOCATION_LIB"/"$GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX"_"$GLOBUS_FLAVOR$SHARED_OBJECT_FILETYPE"




writegsiauthz() {
cat > $GSI_AUTHZ_FILE << EOF
globus_mapping $GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE lcmaps_callout
EOF

chmod 0644 $GSI_AUTHZ_FILE
}



debug() {
    echo "Using the following environment variables:"
    echo

    echo "\$ETC_GRID_SEC                                   " $ETC_GRID_SEC
    echo "\$GSI_AUTHZ_FILE                                 " $GSI_AUTHZ_FILE
    echo "\$prefix                                         " $prefix
    echo "\$LOCATION_LIB                                   " $LOCATION_LIB

    echo 
    echo "\$GLOBUS_FLAVOR                                  " $GLOBUS_FLAVOR
    echo "\$SHARED_OBJECT_FILETYPE                         " $SHARED_OBJECT_FILETYPE
    echo "\$GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX        " $GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX
    echo

    echo "\$GT4_INTERFACE_SHARED_OBJECT_FILE               " $GT4_INTERFACE_SHARED_OBJECT_FILE
    echo "\$GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE " $GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE
    echo 
}


install() {
    if [ -f "$GSI_AUTHZ_FILE" ]; then
        mv -v $GSI_AUTHZ_FILE $GSI_AUTHZ_FILE.is-replaced
    fi

    if [ ! -f "$GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE" ]; then
        if [ ! -f "$GT4_INTERFACE_SHARED_OBJECT_FILE" ]; then
            echo "Error: Interface doesn't exist at '$GT4_INTERFACE_SHARED_OBJECT_FILE'."
            echo "Error: Please search for '$GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$SHARED_OBJECT_FILETYPE' and link it to '$GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$GLOBUS_FLAVOR$SHARED_OBJECT_FILETYPE' and adjust the '$GSI_AUTHZ_FILE' accordingly"
            exit 2;
        else
            # Link at the start place
            ln -s $GT4_INTERFACE_SHARED_OBJECT_FILE $GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE
        fi
    fi


    if [ ! -f $GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE ]; then
        echo "Error: couldn't find the interface file '$GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE' or a (sym)link to the interface"
        exit 3;
    else
        writegsiauthz;
    fi
   
}



deinstall() {
    if [ -f "$GSI_AUTHZ_FILE" ]; then
        mv -v $GSI_AUTHZ_FILE $GSI_AUTHZ_FILE.deinstalled
    fi
}


case "$1" in
    install)
        install;
    ;;

    deinstall)
        deinstall;
    ;;

    debug)
        debug;
    ;;

    *)
        echo $"Usage: $0 {install|deinstall|debug}";
        exit 1;
esac

exit 0;
